Soft Patch Panel
 help / color / mirror / Atom feed
From: ogawa.yasufumi@lab.ntt.co.jp
To: spp@dpdk.org, ferruh.yigit@intel.com, ogawa.yasufumi@lab.ntt.co.jp
Subject: [spp] [PATCH 1/3] shared/sec: rename func for parsing cls table
Date: Tue, 21 May 2019 11:32:40 +0900	[thread overview]
Message-ID: <1558405962-8406-2-git-send-email-ogawa.yasufumi@lab.ntt.co.jp> (raw)
In-Reply-To: <1558405962-8406-1-git-send-email-ogawa.yasufumi@lab.ntt.co.jp>

From: Yasufumi Ogawa <ogawa.yasufumi@lab.ntt.co.jp>

This update is to rename function for parsing and getting index of
action `decode_classifier_action_value()` to `parse_cls_action()`,
and refactor comments and log messages.

Signed-off-by: Yasufumi Ogawa <ogawa.yasufumi@lab.ntt.co.jp>
---
 .../secondary/spp_worker_th/cmd_parser.c      | 31 +++++++++++--------
 1 file changed, 18 insertions(+), 13 deletions(-)

diff --git a/src/shared/secondary/spp_worker_th/cmd_parser.c b/src/shared/secondary/spp_worker_th/cmd_parser.c
index b043b4c..70cf254 100644
--- a/src/shared/secondary/spp_worker_th/cmd_parser.c
+++ b/src/shared/secondary/spp_worker_th/cmd_parser.c
@@ -621,27 +621,32 @@ parse_mac_addr(void *output, const char *arg_val,
 	return SPP_RET_OK;
 }
 
 /* decoding procedure of action for classifier_table command */
 static int
-decode_classifier_action_value(void *output, const char *arg_val,
-				int allow_override __attribute__ ((unused)))
+parse_cls_action(void *output, const char *arg_val,
+		int allow_override __attribute__ ((unused)))
 {
-	int ret = SPP_RET_OK;
-	ret = get_list_idx(arg_val, CMD_ACT_LIST);
-	if (unlikely(ret <= 0)) {
-		RTE_LOG(ERR, SPP_COMMAND_PROC, "Unknown port action. val=%s\n",
+	int idx;
+	idx = get_list_idx(arg_val, CMD_ACT_LIST);
+	if (unlikely(idx <= 0)) {
+		RTE_LOG(ERR, SPP_COMMAND_PROC,
+				"Failed to get index for action `%s`.\n",
 				arg_val);
 		return SPP_RET_NG;
 	}
 
-	if (unlikely(ret != SPPWK_ACT_ADD) &&
-			unlikely(ret != SPPWK_ACT_DEL)) {
-		RTE_LOG(ERR, SPP_COMMAND_PROC, "Unknown port action. val=%s\n",
+	if (unlikely(idx != SPPWK_ACT_ADD) &&
+			unlikely(idx != SPPWK_ACT_DEL)) {
+		RTE_LOG(ERR, SPP_COMMAND_PROC,
+				"Unknown action `%s` for port.\n",
 				arg_val);
 		return SPP_RET_NG;
 	}
 
-	*(int *)output = ret;
+	*(int *)output = idx;
 	return SPP_RET_OK;
 }
 
@@ -748,7 +753,7 @@ cmd_ops_list[][SPPWK_MAX_PARAMS] = {
 			.name = "action",
 			.offset = offsetof(struct spp_command,
 					spec.cls_table.wk_action),
-			.func = decode_classifier_action_value
+			.func = parse_cls_action
 		},
 		{
 			.name = "type",
@@ -775,7 +780,7 @@ cmd_ops_list[][SPPWK_MAX_PARAMS] = {
 			.name = "action",
 			.offset = offsetof(struct spp_command,
 					spec.cls_table.wk_action),
-			.func = decode_classifier_action_value
+			.func = parse_cls_action
 		},
 		{
 			.name = "type",
@@ -621,27 +621,32 @@ parse_mac_addr(void *output, const char *arg_val,
 }
 
-/* decoding procedure of action for classifier_table command */
+/**
+ * Parse given action for getting index of actions for `classifier_table`
+ * command.
+ */
 static int
-- 
2.17.1


  reply	other threads:[~2019-05-21  2:35 UTC|newest]

Thread overview: 4+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-05-21  2:32 [spp] [PATCH 0/3] Refactor func for parsing cls cmd ogawa.yasufumi
2019-05-21  2:32 ` ogawa.yasufumi [this message]
2019-05-21  2:32 ` [spp] [PATCH 2/3] shared/sec: rename func to get type idx for cls ogawa.yasufumi
2019-05-21  2:32 ` [spp] [PATCH 3/3] shared/sec: rename func for parsing VLAN ID ogawa.yasufumi

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1558405962-8406-2-git-send-email-ogawa.yasufumi@lab.ntt.co.jp \
    --to=ogawa.yasufumi@lab.ntt.co.jp \
    --cc=ferruh.yigit@intel.com \
    --cc=spp@dpdk.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).